@@ -74,7 +74,8 @@ gboolean            eog_image_is_loaded                      (EogImage *img);
 
 /* saving API */
 gboolean            eog_image_save                            (EogImage *img, 
-							       const GnomeVFSURI *uri,
+							       GnomeVFSURI *uri,
+							       GdkPixbufFormat *format,
 							       GError **error);
 
 /* query API */
